@@ -2,10 +2,9 @@
      $                   NSVAL, THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
      $                   X, XACT, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     December 7, 1999
+*  -- LAPACK test routine (version 3.1.1) --
+*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..
+*     January 2007
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -166,6 +165,7 @@
 *
 *     Test the error exits
 *
+      CALL XLAENV( 1, 1 )
       IF( TSTERR )
      $   CALL ZERRGE( PATH, NOUT )
       INFOT = 0
